@@ -12,6 +12,10 @@ parse_text <- function(content, type = NULL, encoding = NULL) {
 }
 
 parse_auto <- function(content, type = NULL, encoding = NULL, ...) {
+  if (length(content) == 0) {
+    return(NULL)
+  }
+
   if (is.null(type)) {
     stop("Unknown mime type: can't parse automatically. Use the type ",
       "argument to specify manually.", call. = FALSE)
@@ -37,7 +41,6 @@ parsers <- new.env(parent = emptyenv())
 parsers$`application/json` <- function(x, simplifyVector = FALSE,
                                        simplifyMatrix = FALSE,
                                        simplifyDataFrame = FALSE, ...) {
-  need_package("jsonlite")
   jsonlite::fromJSON(parse_text(x, encoding = "UTF-8"),
     simplifyVector = simplifyVector, simplifyMatrix = simplifyMatrix,
     simplifyDataFrame = simplifyDataFrame, ...)
