@@ -6,7 +6,12 @@ handle_url <- function(handle = NULL, url = NULL, ...) {
   if (is.null(handle))  handle <- find_handle(url)
   if (is.null(url))     url <- handle$url
 
-  url <- modify_url(url, ...)
+  # If named components in ..., modify the url
+  new <- named(list(...))
+  if (length(new) > 0 || is.url(url)) {
+    old <- parse_url(url)
+    url <- build_url(modifyList(old, new))
+  }
 
   list(handle = handle, url = url)
 }
