@@ -25,7 +25,7 @@ handle <- function(url, cookies = TRUE) {
   url <- parse_url(url)
   cookie_path <- if (cookies) tempfile() else NULL
 
-  h <- getCurlHandle(cookiefile = cookie_path, .defaults = list())
+  h <- RCurl::getCurlHandle(cookiefile = cookie_path, .defaults = list())
   structure(list(handle = h, url = url), class = "handle")
 }
 
@@ -41,10 +41,10 @@ ref <- function(x) {
 is.handle <- function(x) inherits(x, "handle")
 
 reset_handle_config <- function(handle, config) {
-  blank <- lapply(config, function(x) NULL)
-  blank$httpauth <- NULL
-  curlSetOpt(.opts = blank, curl = handle$handle)
-
+  # Calls curl_easy_reset (http://curl.haxx.se/libcurl/c/curl_easy_reset.html)
+  # Does not change live connections, session ID cache, DNS cache, cookies
+  # or shares.
+  RCurl::reset(handle$handle)
   invisible(TRUE)
 }
 
