@@ -2,9 +2,7 @@ library(httr)
 
 # 1. Find OAuth settings for facebook:
 #    http://developers.facebook.com/docs/authentication/server-side/
-facebook <- oauth_endpoint(
-  authorize = "https://www.facebook.com/dialog/oauth",
-  access = "https://graph.facebook.com/oauth/access_token")
+oauth_endpoints("facebook")
 
 # 2. Register an application at https://developers.facebook.com/apps/
 #    Insert your values below - if secret is omitted, it will look it up in
@@ -12,6 +10,10 @@ facebook <- oauth_endpoint(
 myapp <- oauth_app("facebook", "353609681364760")
 
 # 3. Get OAuth credentials
-facebook_token <- oauth2.0_token(facebook, myapp,
+facebook_token <- oauth2.0_token(oauth_endpoints("facebook"), myapp,
   type = "application/x-www-form-urlencoded")
-facebook_sig <- sign_oauth2.0(facebook_token$access_token)
+
+# 4. Use API
+req <- GET("https://graph.facebook.com/me", config(token = facebook_token))
+stop_for_status(req)
+str(content(req))
